@@ -223,27 +223,11 @@ sub add_attribute {
     return $attr;
 }
 
-sub compute_all_applicable_attributes { # DEPRECATED
-    Carp::cluck('compute_all_applicable_attributes() has been deprecated. Use get_all_attributes() instead');
-
-    return shift->get_all_attributes(@_)
-}
-
 sub linearized_isa;
 
 sub new_object;
 sub clone_object;
 
-
-sub clone_instance { # DEPRECATED
-    my ($class, $instance, %params) = @_;
-
-    Carp::cluck('clone_instance() has been deprecated. Use clone_object() instead');
-
-    return $class->clone_object($instance, %params);
-}
-
-
 sub immutable_options {
     my ( $self, @args ) = @_;
 
@@ -255,7 +239,6 @@ sub immutable_options {
     );
 }
 
-
 sub make_immutable {
     my $self = shift;
     my %args = $self->immutable_options(@_);
@@ -490,7 +473,7 @@ Mouse::Meta::Class - The Mouse class metaclass
 
 =head1 VERSION
 
-This document describes Mouse version 0.64
+This document describes Mouse version 0.65
 
 =head1 METHODS
 
