@@ -52,9 +52,9 @@ BEGIN{
     # Because Mouse::Util is loaded first in all the Mouse sub-modules,
     # XS loader is placed here, not in Mouse.pm.
 
-    our $VERSION = '0.64';
+    our $VERSION = '0.65';
 
-    my $xs = !(exists $INC{'Mouse/PurePerl.pm'} || $ENV{MOUSE_PUREPERL});
+    my $xs = !(exists $INC{'Mouse/PurePerl.pm'} || $ENV{MOUSE_PUREPERL} || $ENV{PERL_ONLY});
 
     if($xs){
         # XXX: XSLoader tries to get the object path from caller's file name
@@ -365,7 +365,7 @@ Mouse::Util - Features, with or without their dependencies
 
 =head1 VERSION
 
-This document describes Mouse version 0.64
+This document describes Mouse version 0.65
 
 =head1 IMPLEMENTATIONS FOR
 
